@@ -1,13 +1,13 @@
 ! ==============================================================================
 !   GRAMMAR:  Grammar table entries for the standard verbs library.
 !
-!   Supplied for use with Inform 6 -- Release 6/12 -- Serial number 151220
+!   Supplied for use with Inform 6 -- Release 6.12.2 -- Serial number 180611
 !
-!   Copyright Graham Nelson 1993-2004 and David Griffith 2012-2015
+!   Copyright Graham Nelson 1993-2004 and David Griffith 2012-2018
 !   This code is licensed under either the traditional Inform license as
 !   described by the DM4 or the Artistic License version 2.0.  See the
 !   file COPYING in the distribution archive or at
-!   https://github.com/DavidGriffith/inform6lib/
+!   https://gitlab.com/DavidGriffith/inform6lib/
 !
 !   In your game file, Include three library files in this order:
 !       Include "Parser";
@@ -276,8 +276,8 @@ Verb 'get'
     * multiinside 'from'/'off' noun             -> Remove;
 
 Verb 'give' 'feed' 'offer' 'pay'
-    * held 'to' creature                        -> Give
     * creature held                             -> Give reverse
+    * held 'to' creature                        -> Give
     * 'over' held 'to' creature                 -> Give;
 
 Verb 'go' 'run' 'walk'
