@@ -1,14 +1,13 @@
 ! ==============================================================================
 !   INFIX:  Support for the optional library debugger extension "Infix".
 !
-!   Supplied for use with Inform 6 -- Release 6/12 -- Serial number 151220
+!   Supplied for use with Inform 6 -- Release 6.12.2 -- Serial number 180611
 !
-!   Copyright Graham Nelson 1993-2004 and David Griffith 2012-2015
+!   Copyright Graham Nelson 1993-2004 and David Griffith 2012-2018
 !
 !   This code is licensed under either the traditional Inform license as
 !   described by the DM4 or the Artistic License version 2.0.  See the
-!   file COPYING in the distribution archive or at
-!   https://github.com/DavidGriffith/inform6lib/
+!   file COPYING in the distribution archive.
 !
 !   This file is automatically Included in your game file by "Grammar" if you
 !   supply the -X compiler switch.
@@ -798,15 +797,16 @@ Array InfixRV_commas --> 32;
     else   @astorebit noun t 1; ! give noun second;
     #Endif; ! TARGET_
     if (t);  ! quell unused n variable warning
+    new_line;
 ];
 
 [ InfixMoveSub;
-    print "; move (", (the) noun, ") to (", (the) second, ")";
+    print "; move (", (the) noun, ") to (", (the) second, ")^";
     move noun to second;
 ];
 
 [ InfixRemoveSub;
-    print "; remove (", (the) noun, ")";
+    print "; remove (", (the) noun, ")^";
     remove noun;
 ];
 
@@ -967,7 +967,7 @@ Array InfixRV_commas --> 32;
         for (b=0 : b < #dictionary_table-->0 : b++) {
             w = #dictionary_table + WORDSIZE + b*(DICT_WORD_SIZE + 7);
             if ((w->#dict_par1) & 1) {
-                a = (#grammar_table)-->($100-(w->#dict_par2));
+                a = (#grammar_table)-->(DictionaryWordToVerbNum(w) + 1);
                 lines = a->0; a++;
                 for (: lines>0 : lines--) {
                     a = UnpackGrammarLine(a);
@@ -994,6 +994,7 @@ Array InfixRV_commas --> 32;
         if (noun == true) "; true"; if (noun == false) "; false";
         "; ", noun;
     }
+    new_line;
 ]; ! end of InfixExamineP
 
 [ InfixDescribeWatchSub x y z s flag aflag;
